==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Prikaz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Napravi ravninu slike ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Napravi planarnu sliku u 3D prostoru</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>stvoriti planarnu sliku u 3D prikazu</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Prikaz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Otvori ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Otvori pogled slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>nedefinirani tip boja za gledanje slika</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>format slike u pixelima</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Odaberite orijentaciju</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Ploha slike</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY ravnina</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ-Ravnina</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ-Ravnina</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Obrnutim smjerom</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Odmak:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>Prilagodi sliku</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>rastegni sliku da odgovara prikazu</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>u mjerilu 1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaz slike u mjerilu 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation> I originalna boja</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Prikaži sliku s originalnim bojama</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>I  Razvedri boju</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Prikaži sliku s s izbjeljenim bojama</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Spreman...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zum</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>izvan slike</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Pregled slike</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Slike (*. png *. XPM *. jpg *. bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Odaberite koju ce te sliku otvoriti</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Slike</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Sve datoteke</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Greška pri otvaranju slike</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Nije moguće učitati odabranu sliku</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Pogreška pri otvaranju slike</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nije moguće učitati izabranu sliku</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Prikaz</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Prikaz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Napravi ravninu slike ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Napravi planarnu sliku u 3D prostoru</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>stvoriti planarnu sliku u 3D prikazu</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Prikaz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Otvori ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Otvori pogled slike</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Prikaz</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Skalirajte...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Promjena veličine slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>nedefinirani tip boja za gledanje slika</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>format slike u pixelima</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Odaberite orijentaciju</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Ploha slike</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY ravnina</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ-Ravnina</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ-Ravnina</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Obrnutim smjerom</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Odmak:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>Prilagodi sliku</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>rastegni sliku da odgovara prikazu</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>u mjerilu 1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaz slike u mjerilu 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation> I originalna boja</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Prikaži sliku s originalnim bojama</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>I  Razvedri boju</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Prikaži sliku s s izbjeljenim bojama</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Spreman...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zum</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>izvan slike</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Pregled slike</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Slike (*. png *. XPM *. jpg *. bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Odaberite koju ce te sliku otvoriti</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Slike</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Sve datoteke</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Greška pri otvaranju slike</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Nije moguće učitati odabranu sliku</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Pogreška pri otvaranju slike</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nije moguće učitati izabranu sliku</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Prikaz</translation>
    </message>
  </context>
</TS>
